@@ -1,53 +1,33 @@
-/*****************************************************************************
- * Copyright (C) 2009 by Peter Penz <peter.penz@gmx.at>                      *
- * Copyright (C) 2014 by Vishesh Handa <me@vhanda.in>                        *
- * Copyright (C) 2017 by James D. Smith <smithjd15@gmail.com                    *
- *                                                                           *
- * This library is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU Library General Public               *
- * License version 2 as published by the Free Software Foundation.           *
- *                                                                           *
- * This library is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
- * Library General Public License for more details.                          *
- *                                                                           *
- * You should have received a copy of the GNU Library General Public License *
- * along with this library; see the file COPYING.LIB.  If not, write to      *
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- * Boston, MA 02110-1301, USA.                                               *
- *****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2014 Vishesh Handa <me@vhanda.in>
+    SPDX-FileCopyrightText: 2017 James D. Smith <smithjd15@gmail.com
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "kedittagsdialog_p.h"
 
 #include <KLocalizedString>
 
-#include <QLineEdit>
+#include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QLabel>
-#include <QTreeWidget>
+#include <QLineEdit>
 #include <QPushButton>
-#include <QTimer>
+#include <QTreeWidget>
 #include <QVBoxLayout>
 #include <QWidget>
-#include <QUrl>
-#include <QDialogButtonBox>
-#include <QDebug>
 
 #include <Baloo/TagListJob>
 
-KEditTagsDialog::KEditTagsDialog(const QStringList& tags,
-                                 QWidget *parent) :
-    QDialog(parent),
-    m_tags(tags),
-    m_tagTree(nullptr),
-    m_newTagEdit(nullptr)
+KEditTagsDialog::KEditTagsDialog(const QStringList &tags, QWidget *parent)
+    : QDialog(parent)
+    , m_tags(tags)
 {
-    const QString captionText = (tags.count() > 0) ?
-                                i18nc("@title:window", "Edit Tags") :
-                                i18nc("@title:window", "Add Tags");
+    const QString captionText = (tags.count() > 0) ? i18nc("@title:window", "Edit Tags") : i18nc("@title:window", "Add Tags");
     setWindowTitle(captionText);
-    QDialogButtonBox* buttonBox = new QDialogButtonBox(this);
+    auto buttonBox = new QDialogButtonBox(this);
 
     buttonBox->addButton(i18n("Save"), QDialogButtonBox::AcceptRole);
     buttonBox->addButton(QDialogButtonBox::Cancel);
@@ -55,26 +35,27 @@ KEditTagsDialog::KEditTagsDialog(const QStringList& tags,
     connect(buttonBox, &QDialogButtonBox::accepted, this, &KEditTagsDialog::slotAcceptedButtonClicked);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
-    QVBoxLayout* topLayout = new QVBoxLayout;
+    auto topLayout = new QVBoxLayout;
     setLayout(topLayout);
 
-    QLabel* label = new QLabel(i18nc("@label:textbox",
-                                     "Configure which tags should "
-                                     "be applied."), this);
+    auto label = new QLabel(i18nc("@label:textbox",
+                                  "Configure which tags should "
+                                  "be applied."),
+                            this);
 
     m_tagTree = new QTreeWidget();
     m_tagTree->setSortingEnabled(true);
     m_tagTree->setSelectionMode(QAbstractItemView::NoSelection);
     m_tagTree->setHeaderHidden(true);
 
-    QLabel* newTagLabel = new QLabel(i18nc("@label", "Create new tag:"));
+    auto newTagLabel = new QLabel(i18nc("@label", "Create new tag:"));
     m_newTagEdit = new QLineEdit(this);
     m_newTagEdit->setClearButtonEnabled(true);
     m_newTagEdit->setFocus();
     connect(m_newTagEdit, &QLineEdit::textEdited, this, &KEditTagsDialog::slotTextEdited);
     connect(m_tagTree, &QTreeWidget::itemActivated, this, &KEditTagsDialog::slotItemActivated);
 
-    QHBoxLayout* newTagLayout = new QHBoxLayout();
+    auto newTagLayout = new QHBoxLayout();
     newTagLayout->addWidget(newTagLabel);
     newTagLayout->addWidget(m_newTagEdit, 1);
 
@@ -85,9 +66,9 @@ KEditTagsDialog::KEditTagsDialog(const QStringList& tags,
 
     resize(sizeHint());
 
-    Baloo::TagListJob* job = new Baloo::TagListJob();
-    connect(job, &Baloo::TagListJob::finished, [this] (KJob* job) {
-        Baloo::TagListJob* tjob = static_cast<Baloo::TagListJob*>(job);
+    auto job = new Baloo::TagListJob();
+    connect(job, &Baloo::TagListJob::finished, [this](KJob *job) {
+        auto tjob = static_cast<Baloo::TagListJob *>(job);
         m_allTags = tjob->tags();
         loadTagWidget();
     });
@@ -95,9 +76,7 @@ KEditTagsDialog::KEditTagsDialog(const QStringList& tags,
     job->start();
 }
 
-KEditTagsDialog::~KEditTagsDialog()
-{
-}
+KEditTagsDialog::~KEditTagsDialog() = default;
 
 QStringList KEditTagsDialog::tags() const
 {
@@ -108,7 +87,7 @@ void KEditTagsDialog::slotAcceptedButtonClicked()
 {
     m_tags.clear();
 
-    for (const QTreeWidgetItem* item : m_allTagTreeItems.values()) {
+    for (const QTreeWidgetItem *item : std::as_const(m_allTagTreeItems)) {
         if (item->checkState(0) == Qt::Checked) {
             m_tags << qvariant_cast<QString>(item->data(0, Qt::UserRole));
         }
@@ -117,16 +96,16 @@ void KEditTagsDialog::slotAcceptedButtonClicked()
     accept();
 }
 
-void KEditTagsDialog::slotItemActivated(const QTreeWidgetItem* item, int column)
+void KEditTagsDialog::slotItemActivated(const QTreeWidgetItem *item, int column)
 {
     Q_UNUSED(column)
 
-    const QString tag = qvariant_cast<QString>(item->data(0, Qt::UserRole));
+    const auto tag = qvariant_cast<QString>(item->data(0, Qt::UserRole));
     m_newTagEdit->setText(tag + QLatin1Char('/'));
     m_newTagEdit->setFocus();
 }
 
-void KEditTagsDialog::slotTextEdited(const QString& text)
+void KEditTagsDialog::slotTextEdited(const QString &text)
 {
     // Remove unnecessary spaces from a new tag is
     // mandatory, as the user cannot see the difference
@@ -139,14 +118,14 @@ void KEditTagsDialog::slotTextEdited(const QString& text)
     }
 
     // Remove all tree items related to the previous new tag
-    const QStringList splitTag = m_newTag.split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList splitTag = m_newTag.split(QLatin1Char('/'), Qt::SkipEmptyParts);
     for (int i = splitTag.size() - 1; i >= 0 && i < splitTag.size(); --i) {
         QString itemTag = m_newTag.section(QLatin1Char('/'), 0, i, QString::SectionSkipEmpty);
-        QTreeWidgetItem* item = m_allTagTreeItems.value(itemTag);
+        QTreeWidgetItem *item = m_allTagTreeItems.value(itemTag);
 
         if (!m_allTags.contains(m_newTag) && (item->childCount() == 0)) {
             if (i != 0) {
-                QTreeWidgetItem* parentItem = item->parent();
+                QTreeWidgetItem *parentItem = item->parent();
                 parentItem->removeChild(item);
             } else {
                 const int row = m_tagTree->indexOfTopLevelItem(item);
@@ -177,11 +156,11 @@ void KEditTagsDialog::slotTextEdited(const QString& text)
 
 void KEditTagsDialog::loadTagWidget()
 {
-    for (const QString &tag : m_tags) {
+    for (const QString &tag : std::as_const(m_tags)) {
         modifyTagWidget(tag);
     }
 
-    for (const QString &tag : m_allTags) {
+    for (const QString &tag : std::as_const(m_allTags)) {
         modifyTagWidget(tag);
     }
 
@@ -190,18 +169,19 @@ void KEditTagsDialog::loadTagWidget()
 
 void KEditTagsDialog::modifyTagWidget(const QString &tag)
 {
-    const QStringList splitTag = tag.split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList splitTag = tag.split(QLatin1Char('/'), Qt::SkipEmptyParts);
     for (int i = 0; i < splitTag.size(); ++i) {
-        QTreeWidgetItem* item = new QTreeWidgetItem();
+        QTreeWidgetItem *item;
         QString itemTag = tag.section(QLatin1Char('/'), 0, i, QString::SectionSkipEmpty);
 
         if (!m_allTagTreeItems.contains(itemTag)) {
+            item = new QTreeWidgetItem();
             item->setText(0, splitTag.at(i));
             item->setIcon(0, QIcon::fromTheme(QLatin1String("tag")));
             item->setData(0, Qt::UserRole, itemTag);
             m_allTagTreeItems.insert(itemTag, item);
             QString parentTag = tag.section(QLatin1Char('/'), 0, (i - 1), QString::SectionSkipEmpty);
-            QTreeWidgetItem* parentItem = m_allTagTreeItems.value(parentTag);
+            QTreeWidgetItem *parentItem = m_allTagTreeItems.value(parentTag);
 
             if (i != 0) {
                 parentItem->addChild(item);
@@ -226,3 +206,5 @@ void KEditTagsDialog::modifyTagWidget(const QString &tag)
         item->setCheckState(0, check ? Qt::Checked : Qt::Unchecked);
     }
 }
+
+#include "moc_kedittagsdialog_p.cpp"
